from setuptools import setup, find_packages

setup(
    name="mypassgen",
    version="1.0.0",
    packages=find_packages(),
    install_requires=[
        # List any dependencies here
    ],
    author="Anup Ghosh",
    author_email="anupbsmrstu@gmail.com",
    description="An example of a custom library",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)


import random
import string

def generate_pass(length: int, uppercase: bool = True, lowercase: bool = True, numbers: bool = True, special: bool = False) -> str:
    """
    Generate a random password with the specified length and character types.
    
    :param length: The length of the password to generate
    :param uppercase: Include uppercase letters in the password
    :param lowercase: Include lowercase letters in the password
    :param numbers: Include numbers in the password
    :param special: Include special characters in the password
    :return: A random password with the specified length and character types
    """
    # Define the character sets to use
    characters = ""
    if uppercase:
        characters += string.ascii_uppercase
    if lowercase:
        characters += string.ascii_lowercase
    if numbers:
        characters += string.digits
    if special:
        characters += string.punctuation

    # Generate the ID
    return "".join(random.choice(characters) for _ in range(length))
    

   